@@ -23,14 +23,19 @@ TestView::~TestView()
     setStatus(Disconnected);
 }
 
-bool TestView::eventFilter(QObject *obj, QEvent *event)
+void TestView::handleKeyEvent(QKeyEvent *event)
 {
-    if (m_viewOnly) {
-        if (event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease || event->type() == QEvent::MouseButtonDblClick
-            || event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonRelease || event->type() == QEvent::MouseMove)
-            return true;
-    }
-    return RemoteView::eventFilter(obj, event);
+    Q_UNUSED(event);
+}
+
+void TestView::handleMouseEvent(QMouseEvent *event)
+{
+    Q_UNUSED(event);
+}
+
+void TestView::handleWheelEvent(QWheelEvent *event)
+{
+    Q_UNUSED(event);
 }
 
 void TestView::asyncConnect()
@@ -81,3 +86,8 @@ void TestView::switchFullscreen(bool on)
 {
     Q_UNUSED(on);
 }
+
+void TestView::handleLocalClipboardChanged(const QMimeData *data)
+{
+    Q_UNUSED(data);
+}
\ No newline at end of file
